EphemeralSecret

Struct EphemeralSecret 

pub struct EphemeralSecret(pub(crate) Array<u8, U56>);
An EphemeralSecret is a Scalar on Curve448.

Tuple Fields

0: Array<u8, U56>

Implementations

Source

impl EphemeralSecret

pub fn new<R>(csprng: &mut R) -> Self
where R: CryptoRng + ?Sized,

👎Deprecated since 0.14.0: use the Generate trait instead

DEPRECATED: Generate a new ephemeral secret from the given RNG.

pub(crate) fn as_scalar(&self) -> Scalar<Ed448>

Views an Secret as a Scalar

pub fn diffie_hellman(&self, public_key: &PublicKey) -> SharedSecret

Performs a Diffie-hellman key exchange between the secret key and an external public key

pub fn as_bytes(&self) -> &[u8; 56]

Converts a secret into a byte array

pub(crate) fn clamp(bytes: Array<u8, U56>) -> Self

Construct an EphemeralSecret by the secret key according to RFC7748.