PublicKey

Struct PublicKey 

pub struct PublicKey(pub(crate) MontgomeryPoint);
A PublicKey is a point on Curve448.

Tuple Fields

0: MontgomeryPoint

Implementations

Source

impl PublicKey

pub fn from_bytes(bytes: &[u8]) -> Option<PublicKey>

Converts a bytes slice into a Public key Returns None if:

  • The length of the slice is not 56
  • The point is a low order point
pub fn from_bytes_unchecked(bytes: &[u8]) -> Option<PublicKey>

Converts a bytes slice into a Public key Returns None if:

  • The length of the slice is not 56
pub fn as_bytes(&self) -> &[u8; 56]

Converts a public key into a byte slice