pub struct EphemeralSecret(pub(crate) Array<u8, U56>);Expand description
An EphemeralSecret is a Scalar on Curve448.
Tuple Fields
0: Array<u8, U56>Implementations
Sourceimpl EphemeralSecret
impl EphemeralSecret
Sourcepub fn new<R>(csprng: &mut R) -> Self
👎Deprecated since 0.14.0: use the Generate trait instead
pub fn new<R>(csprng: &mut R) -> Self
Generate trait insteadDEPRECATED: Generate a new ephemeral secret from the given RNG.
Sourcepub fn diffie_hellman(&self, public_key: &PublicKey) -> SharedSecret
pub fn diffie_hellman(&self, public_key: &PublicKey) -> SharedSecret
Performs a Diffie-hellman key exchange between the secret key and an external public key