pub struct PublicKey(pub(crate) MontgomeryPoint);Expand description
A PublicKey is a point on Curve448.
Tuple Fields
0: MontgomeryPointImplementations
Sourceimpl PublicKey
impl PublicKey
Sourcepub fn from_bytes(bytes: &[u8]) -> Option<PublicKey>
pub fn from_bytes(bytes: &[u8]) -> Option<PublicKey>
Converts a bytes slice into a Public key Returns None if:
- The length of the slice is not 56
- The point is a low order point
Sourcepub fn from_bytes_unchecked(bytes: &[u8]) -> Option<PublicKey>
pub fn from_bytes_unchecked(bytes: &[u8]) -> Option<PublicKey>
Converts a bytes slice into a Public key Returns None if:
- The length of the slice is not 56